@@ -10,11 +10,11 @@ HTML::FormHandlerX::JQueryRemoteValidator - call server-side validation code asy
 
 =head1 VERSION
 
-Version 0.2
+Version 0.21
 
 =cut
 
-our $VERSION = '0.2';
+our $VERSION = '0.21';
 
 
 =head1 SYNOPSIS
@@ -170,18 +170,17 @@ has 'jquery_validator_opts' => (is => 'rw', isa => 'HashRef[Str]', required => 0
 
 =head1 CONFIGURATION AND SETUP
 
-The purpose of this package is to automatically build a set of JQuery scripts
-and inject them into your forms. The scripts send user input to your server
-where you must provide an endpoint that can validate the fields. Since you
-already have an HTML::FormHandler form, you can use that. The synopsis has a
-straightforward example of how to do it. 
+The purpose of this package is to build a set of JQuery scripts and inject them
+into your forms. The scripts send user input to your server where you must
+provide an endpoint that can validate the fields. Since you already have an
+HTML::FormHandler form, you can use that.
 
 The package uses the remote validation feature of the JQuery Validator
 framework. This also takes care of updating your form to notify the user of
-errors and successes while they fill in the form, but you will most likely want
+errors and successes while they fill in the form. You will most likely want
 to customise that behaviour for your own situation. An example is given below.
 
-=head2 What you need
+=head2 What you will need
 
 =over 4
 
@@ -245,9 +244,9 @@ JQuery validator targets error messages to the second <label> on each
 form-control. This is the default behaviour but can be changed. 
 
 The default setup will display and remove messages as the user progresses
-through the form, but for a better user experience JQuery Validator offers lots
-of options. You can read about them at L<http://jqueryvalidation.org/validate/>.
-You should start by reading the few sentences at the very bottom of that page.
+through the form. JQuery Validator offers lots of options. You can read about
+them at L<http://jqueryvalidation.org/validate/>. You should start by reading
+the few sentences at the very bottom of that page.
 
 Some useful additional styling to get started:
 
@@ -325,7 +324,7 @@ etc. as described there.
 
 =head3 C<skip_remote_validation_types>
 
-Default: C<[ qw(Hidden noCAPTCHA Display JSON JavaScript) ]>
+Default: C<[ qw(Submit Hidden noCAPTCHA Display JSON JavaScript) ]>
 
 A list of field types that should not be included in the validation calls.
 
